@@ -1,6 +1,6 @@
 /* Blackfin Ethernet Media Access Controller (EMAC) model.
 
-   Copyright (C) 2010-2017 Free Software Foundation, Inc.
+   Copyright (C) 2010-2025 Free Software Foundation, Inc.
    Contributed by Analog Devices, Inc.
 
    This file is part of simulators.
@@ -18,7 +18,8 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#include "config.h"
+/* This must come before any other includes.  */
+#include "defs.h"
 
 #include <errno.h>
 #include <fcntl.h>
@@ -184,7 +185,7 @@ bfin_emac_io_write_buffer (struct hw *me, const void *source,
   value = dv_load_4 (source);
 
   mmr_off = addr - emac->base;
-  valuep = (void *)((unsigned long)emac + mmr_base() + mmr_off);
+  valuep = (void *)((uintptr_t)emac + mmr_base() + mmr_off);
 
   HW_TRACE_WRITE ();
 
@@ -285,7 +286,7 @@ bfin_emac_io_read_buffer (struct hw *me, void *dest,
     return 0;
 
   mmr_off = addr - emac->base;
-  valuep = (void *)((unsigned long)emac + mmr_base() + mmr_off);
+  valuep = (void *)((uintptr_t)emac + mmr_base() + mmr_off);
 
   HW_TRACE_READ ();
 
@@ -538,11 +539,8 @@ bfin_emac_tap_init (struct hw *me)
 {
 #if WITH_TUN
   struct bfin_emac *emac = hw_data (me);
-  const hw_unit *unit;
   int flags;
 
-  unit = hw_unit_address (me);
-
   emac->tap = open ("/dev/net/tun", O_RDWR);
   if (emac->tap == -1)
     {
